TestRunSuccessfulTests
setTimeout | 120000 |
open | ../core/TestRunner.html?test=../tests/PassingTestSuite.html |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
click | runSuite |
waitForText | testRuns | 2
verifyText | commandPasses | 31
verifyText | testFailures | 0
verifyText | commandFailures | 0
verifyText | commandErrors | 0
verifyAttribute | passingSuite@class | regex:status_passed
verifyAttribute | passingTest@class | regex:status_passed